<?php
/**
 * Theme configuration file
 *
 * @package WordPress
 * @subpackage BarberPro
 * @version 2.0.8
 */

/**
 * Set color scheme
 *
 * Add csutom color scheme
 *
 * @param array $color_scheme
 * @param array $color_scheme
 */
function barberpro_set_color_schemes( $color_scheme ) {

	$color_scheme['light'] = array(
		'label'  => esc_html__( 'Light', 'barberpro' ),
		'colors' => array(
			'#ffffff', // bg
			'#ffffff', // page bg
			'#bc9321', // accent
			'#666', // main text
			'#777777', // second text
			'#333333', // strong text
			'#333333', // submenu
			'#ffffff', // content frame
			'#bc9321', // shop tabs background
			'#ffffff', // shop tabs text
		)
	);

	$color_scheme['dark'] = array(
		'label'  => esc_html__( 'Dark', 'barberpro' ),
		'colors' => array(
			'#262626', // bg
			'#1a1a1a', // page bg
			'#bc9321', // accent
			'#e5e5e5', // main text
			'#c1c1c1', // second text
			'#FFFFFF', // strong text
			'#282828', // submenu
			'#0d0d0d', // content frame
			'#bc9321', // shop tabs background
			'#ffffff', // shop tabs text
		)
	);

	return $color_scheme;
}
add_filter( 'barberpro_color_schemes', 'barberpro_set_color_schemes' );

/**
 * Add additional theme support
 */
function barberpro_additional_theme_support() {

	/**
	 * Enable WooCommerce support
	 */
	add_theme_support( 'woocommerce' );
}
add_action( 'after_setup_theme', 'barberpro_additional_theme_support' );

/**
 * Add post display options
 *
 * @param array $options
 * @param array $options
 */
function barberpro_add_blog_display_options( $options ) {

	$new_options = array(
		'standard' => esc_html__( 'Standard', 'barberpro' ),
		'grid' => esc_html__( 'Square grid', 'barberpro' ),
		'grid3' => esc_html__( 'Portrait grid', 'barberpro' ),
		'column' => esc_html__( 'Columns', 'barberpro' ),
		'masonry' => esc_html__( 'Masonry', 'barberpro' ),
		'metro' => esc_html__( 'Metro', 'barberpro' ),
		'medium-image' => esc_html__( 'Medium image', 'barberpro' ),
		'photo' => esc_html__( 'Photo', 'barberpro' ),
	);

	$options = array_merge( $new_options, $options );
	
	return $options;
}
add_filter( 'barberpro_blog_display_options', 'barberpro_add_blog_display_options' );

/**
 * Add shop product display options
 *
 * @param array $options
 * @param array $options
 */
function barberpro_add_shop_display_options( $options ) {

	if ( class_exists( 'WooCommerce' ) ) {
		$options['loren'] = esc_html__( 'Loren', 'barberpro' );
		$options['agathe'] = esc_html__( 'Agathe', 'barberpro' );
	}

	return $options;
}
add_filter( 'barberpro_shop_display_options', 'barberpro_add_shop_display_options' );

/**
 * Inject theme button style params
 *
 * @param array $button_types
 * @return array $button_types
 */
function barberpro_add_theme_button_type( $button_types ) {
	
	$additional_button_types = array();
	$additional_button_types['wolf-wpb-button'] = esc_html__( 'Theme Accent Color', 'barberpro' );

	return $additional_button_types + $button_types;
}
add_filter( 'wpb_button_types', 'barberpro_add_theme_button_type' );