<?php
/**
 * BarberPro functions and definitions
 *
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 *
 * @package WordPress
 * @subpackage BarberPro
 * @since 1.0.0
 * @version 2.0.8
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( ! function_exists( 'barberpro_setup_config' ) ) {
	/**
	 * Sets up theme defaults and registers support for various WordPress features using the Wolf_Theme_Framework class
	 */
	function barberpro_setup_config() {
		/**
		 * Set the content width based on the theme's design and stylesheet.
		 *
		 * @since BarberPro 1.0.0
		 */
		$GLOBALS['content_width'] = apply_filters( 'barberpro_content_width', 750 );

		/**
		 *  Require the wolf themes framework core file
		 */
		require_once get_template_directory() . '/wp-wolf-framework/wolf-framework.php';

		/**
		 * Set theme main settings
		 *
		 * We this array to configure the main theme settings
		 */
		$barberpro_theme = array(

			/* Menus (id => name) */
			'menus' => array(
				'primary-left' => esc_html__( 'Main Menu Left Part', 'barberpro' ),
				'primary-right' => esc_html__( 'Main Menu Right Part', 'barberpro' ),
				'primary' => esc_html__( 'Main Menu Standard', 'barberpro' ),
				'tertiary' => esc_html__( 'Bottom Menu', 'barberpro' ),
			),

			/**
			 *  We define wordpress thumbnail sizes that we will use in our design
			 */
			'images' => array(

				/**
				 * Create Wolf Page Builder image sizes if the plugin is not installed
				 * We will use the same image size names to avoid duplicated image sizes in the case the plugin is active
				 */
				'barberpro-thumb' => array( 640, 360, true ),
				'barberpro-photo' => array( 640, 640, false ),
				'barberpro-video-thumb' => array( 480, 270, true ),
				'barberpro-portrait' => array( 600, 900, true ),
				'barberpro-2x1' => array( 960, 480, true ), // landscape
				'barberpro-2x2' => array( 960, 960, true ), // square
				'barberpro-1x1' => array( 360, 360, true ), // square small
				'barberpro-1x2' => array( 480, 960, true ), // portrait
				'barberpro-XL' => array( 2000, 1500, false ), // XL
			),
		);
		WLFRMK( $barberpro_theme );
	}
} // end if function exists
barberpro_setup_config();