<?php
/**
 * BarberPro metaboxes
 *
 * Register metabox for the theme with the barberpro_do_metaboxes function
 * This function can be overwritten in a child theme
 *
 * @package WordPress
 * @subpackage BarberPro
 * @version 2.0.8
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( ! function_exists( 'barberpro_do_metaboxes' ) ) {
	/**
	 * Set theme metaboxes
	 *
	 * Allow to add specific style options for each page
	 *
	 * @since BarberPro 1.0.0
	 */
	function barberpro_do_metaboxes() {

		/* Header params */
		$barberpro_header_metaboxes = array(
			'header_settings' => array(
				'title' => esc_html__( 'Header Options', 'barberpro' ),
				'page' => apply_filters( 'barberpro_header_settings_post_types', array( 'post', 'page', 'plugin', 'video', 'product', 'gallery', 'theme', 'work', 'show', 'release', 'wpm_playlist', 'we_event', 'theme_documentation', 'plugin_documentation' ) ),
				'help' => esc_html__( 'It will overwrite all other header image settings.', 'barberpro' ),

				'metafields' => array(

					array(
						'label'	=> esc_html__( 'Header Background Type', 'barberpro' ),
						'id'	=> '_post_bg_type',
						'type'	=> 'select',
						'choices' => array(
							'image' => esc_html__( 'Image', 'barberpro' ),
							'video' => esc_html__( 'Video', 'barberpro' ),
						),
					),

					array(
						'label'	=> esc_html__( 'Header Background', 'barberpro' ),
						'id'	=> '_post_bg',
						'type'	=> 'background',
						'dependency' => array( 'element' => '_post_bg_type', 'value' => array( 'image' ) ),
					),

					array(
						'label'	=> esc_html__( 'Header Background Effect', 'barberpro' ),
						'id'	=> '_post_bg_effect',
						'type'	=> 'select',
						'choices' => array(
							'zoomin' => esc_html__( 'Zoom', 'barberpro' ),
							'parallax' => esc_html__( 'Parallax', 'barberpro' ),
							'none' => esc_html__( 'None', 'barberpro' ),
						),
						'dependency' => array( 'element' => '_post_bg_type', 'value' => array( 'image' ) ),
					),

					// array(
					// 	'label'	=> esc_html__( 'Header font color', 'barberpro' ),
					// 	'id'	=> '_post_font_color',
					// 	'type'	=> 'select',
					// 	'choices' => array(
					// 		'' => esc_html__( 'Auto', 'barberpro' ),
					// 		'dark' => esc_html__( 'Dark', 'barberpro' ),
					// 		'light' => esc_html__( 'Light', 'barberpro' ),
					// 	),
					// ),

					array(
						'label'	=> esc_html__( 'Video Background Type', 'barberpro' ),
						'id'	=> '_post_video_bg_type',
						'type'	=> 'select',
						'choices' => array(
							'selfhosted' => esc_html__( 'Self hosted', 'barberpro' ),
							'youtube' => 'Youtube',
						),
						'dependency' => array( 'element' => '_post_bg_type', 'value' => array( 'video' ) ),
					),

					array(
						'label'	=> esc_html__( 'YouTube URL', 'barberpro' ),
						'id'	=> '_post_video_bg_youtube_url',
						'type'	=> 'text',
						'dependency' => array( 'element' => '_post_bg_type', 'value' => array( 'video' ) ),
					),

					array(
						'label'	=> esc_html__( 'Video Background', 'barberpro' ),
						'id'	=> '_post_video_bg',
						'type'	=> 'video',
						'dependency' => array( 'element' => '_post_bg_type', 'value' => array( 'video' ) ),
					),

					array(
						'label'	=> esc_html__( 'Add Header Overlay', 'barberpro' ),
						//'desc'   =>esc_html__( 'Is your image too light or too dark to read the text?', 'barberpro' ),
						'id'	=> '_post_overlay',
						'type'	=> 'select',
						'choices' => array(
							'yes' => esc_html__( 'Yes', 'barberpro' ),
							'' => esc_html__( 'No', 'barberpro' ),
						),
					),

					array(
						'label'	=> esc_html__( 'Overlay Color', 'barberpro' ),
						'id'	=> '_post_overlay_color',
						'type'	=> 'colorpicker',
						'value' 	=> '#000000',
						'dependency' => array( 'element' => '_post_overlay', 'value' => array( 'yes' ) ),
					),

					array(
						'label'	=> esc_html__( 'Overlay Opacity (in percent)', 'barberpro' ),
						'id'	=> '_post_overlay_opacity',
						'desc'	=> esc_html__( 'Adapt the header overlay opacity if needed', 'barberpro' ),
						'type'	=> 'int',
						'value'	=> 40,
						'dependency' => array( 'element' => '_post_overlay', 'value' => array( 'yes' ) ),
					),

				),
			),
		);

		$common_params = array(

				array(
					'label'	=> '',
					'id'	=> '_post_subheading',
					'type'	=> 'text',
				),

				array(
					'label'	=> esc_html__( 'Menu Style', 'barberpro' ),
					'id'	=> '_post_menu_type',
					'type'	=> 'select',
					'choices' => array(
						'' => esc_html__( 'Default (set in the customizer)', 'barberpro' ),
						'standard' => esc_html__( 'Solid', 'barberpro' ),
						'semi-transparent' => esc_html__( 'Semi-transparent White', 'barberpro' ),
						'semi-transparent-black' => esc_html__( 'Semi-transparent Black', 'barberpro' ),
						'transparent' => esc_html__( 'Transparent', 'barberpro' ),
						'absolute' => esc_html__( 'Solid in absolute position', 'barberpro' ),
						'none' => esc_html__( 'Hide menu', 'barberpro' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Page Header Type', 'barberpro' ),
					'id'	=> '_post_header_type',
					'type'	=> 'select',
					'choices' => array(
						'' => esc_html__( 'Default (set in the customizer)', 'barberpro' ),
						'standard' => esc_html__( 'Standard', 'barberpro' ),
						'big' => esc_html__( 'Big', 'barberpro' ),
						'small' => esc_html__( 'Small', 'barberpro' ),
						'breadcrumb' => esc_html__( 'Breadcrumb', 'barberpro' ),
						'none' => esc_html__( 'No header', 'barberpro' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Hide Title', 'barberpro' ),
					'id'	=> '_post_hide_title_text',
					'type'	=> 'checkbox',
				),
				
				array(
					'label'	=> esc_html__( 'Hide featured image on single post/page (if displayed)', 'barberpro' ),
					'id'	=> '_post_hide_featured_image',
					'type'	=> 'checkbox',
				),

				array(
					'label'	=> esc_html__( 'Hide Footer', 'barberpro' ),
					'id'	=> '_post_hide_footer',
					'type'	=> 'checkbox',
				),

				array(
					'label'	=> esc_html__( 'Custom CSS', 'barberpro' ),
					'id'	=> '_post_css',
					'type'	=> 'textarea',
				),
		);
		
		/************** Page options ******************/
		$barberpro_page_metaboxes = array(

			'meta_options' => array(
					
				'title' => esc_html__( 'Page Options', 'barberpro' ),
				'page' => apply_filters( 'barberpro_page_settings_post_types', array( 'post', 'page', 'plugin', 'video', 'product', 'gallery', 'theme', 'work', 'show', 'release', 'wpm_playlist', 'we_event', 'theme_documentation', 'plugin_documentation' ) ),
				'metafields' => array(),
			),
		);

		foreach ( $common_params as $param ) {
			$barberpro_page_metaboxes['meta_options']['metafields'][] = $param;
		}
		
		/************** Post options ******************/
		$barberpro_post_metaboxes = array(

			'meta_options' => array(
				'title' => esc_html__( 'Post Options', 'barberpro' ),
				'page' => array( 'post' ),
				'metafields' => array(
					array(
						'label'	=> esc_html__( 'Post Layout', 'barberpro' ),
						'id'	=> '_single_post_layout',
						'type'	=> 'select',
						'choices' => array(
							'small-width' => esc_html__( 'Standard', 'barberpro' ),
							'full-width' => esc_html__( 'Full width', 'barberpro' ),
							'sidebar' => esc_html__( 'Sidebar', 'barberpro' ),
							'split' => esc_html__( 'Split', 'barberpro' ),
						),
					),

					array(
						'label'	=> esc_html__( 'Thumbnail Size (for metro layout only)', 'barberpro' ),
						'id'	=> '_single_post_metro_thumbnail_size',
						'type'	=> 'select',
						'choices' => array(
							'' => esc_html__( 'Auto (depends on post format)', 'barberpro' ),
							'small-square' => esc_html__( 'Small square', 'barberpro' ),
							'big-square' => esc_html__( 'Big square', 'barberpro' ),
							'landscape' => esc_html__( 'Landscape', 'barberpro' ),
							'portrait' => esc_html__( 'Portrait', 'barberpro' ),
						),
					),
				),
			),
		);

		foreach ( $common_params as $param ) {
			$barberpro_post_metaboxes['meta_options']['metafields'][] = $param;
		}

		/************** Gallery options ******************/
		$barberpro_gallery_metaboxes = array(

			'meta_options' => array(
				'title' => esc_html__( 'Gallery Options', 'barberpro' ),
				'page' => array( 'gallery' ),
				'metafields' => array(
					array(
						'label'	=> esc_html__( 'Gallery Layout', 'barberpro' ),
						'id'	=> '_single_gallery_layout',
						'type'	=> 'select',
						'choices' => array(
							'standard' => esc_html__( 'Standard', 'barberpro' ),
							'large-width' => esc_html__( 'Large width', 'barberpro' ),
							'full-width' => esc_html__( 'Full window', 'barberpro' ),
						),
					),
				),
			),
		);

		foreach ( $common_params as $param ) {
			$barberpro_gallery_metaboxes['meta_options']['metafields'][] = $param;
		}

		/************** Portfolio options ******************/
		$barberpro_work_metaboxes = array(

			'meta_options' => array(
				'title' => esc_html__( 'Work Options', 'barberpro' ),
				'page' => array( 'work' ),
				'metafields' => array(
					array(
						'label'	=> esc_html__( 'Work Layout', 'barberpro' ),
						'id'	=> '_single_work_layout',
						'type'	=> 'select',
						'choices' => array(
							'small-width' => esc_html__( 'Standard', 'barberpro' ),
							'full-width' => esc_html__( 'Full width', 'barberpro' ),
							'sidebar' => esc_html__( 'Sidebar', 'barberpro' ),
							'split' => esc_html__( 'Split', 'barberpro' ),
						),
					),
				),
			),
		);

		foreach ( $common_params as $param ) {
			$barberpro_work_metaboxes['meta_options']['metafields'][] = $param;
		}
		
		$barberpro_do_page_metaboxes = new Wolf_Theme_Admin_Metabox( apply_filters( 'barberpro_page_metaboxes',  $barberpro_page_metaboxes ) );
		$barberpro_do_post_metaboxes = new Wolf_Theme_Admin_Metabox( apply_filters( 'barberpro_post_metaboxes',  $barberpro_post_metaboxes ) );
		$barberpro_do_gallery_metaboxes = new Wolf_Theme_Admin_Metabox( apply_filters( 'barberpro_gallery_metaboxes',  $barberpro_gallery_metaboxes ) );
		$barberpro_do_work_metaboxes = new Wolf_Theme_Admin_Metabox( apply_filters( 'barberpro_work_metaboxes',  $barberpro_work_metaboxes ) );
		$barberpro_do_header_metaboxes = new Wolf_Theme_Admin_Metabox( apply_filters( 'barberpro_header_metaboxes',  $barberpro_header_metaboxes ) );
	}

	barberpro_do_metaboxes(); // do metaboxes
}