<?php
/**
 * BarberPro fonts
 *
 * @package WordPress
 * @subpackage BarberPro
 * @since BarberPro 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

function barberpro_set_fonts_mods( $barberpro_mods ) {

	$barberpro_google_fonts = apply_filters( 'barberpro_customizer_font_choices', barberpro_get_google_fonts_options() );
	$barberpro_font_choices = array( 'default' => esc_html__( 'Default', 'barberpro' ) );

	foreach ( $barberpro_google_fonts as $key => $value ) {
		$barberpro_font_choices[ $key ] = $key;
	}

	$barberpro_mods['fonts'] = array(
		'id' => 'fonts',
		'title' => esc_html__( 'Fonts', 'barberpro' ),
		'icon' => 'editor-textcolor',
		'options' => array(),
	);

	$barberpro_mods['fonts']['options']['body_font_name'] = array(
		'label' => esc_html__( 'Body Font Name', 'barberpro' ),
		'id' => 'body_font_name',
		'type' => 'text',
		'description' => sprintf( wp_kses(
				__( 'A loaded google font or any <a href="%s" title="more infos" target="_blank">native browser fonts</a>.', 'barberpro' ),
				array( 'a' => array( 'href' => array(), 'target' => array(), 'title' => array(), ), )
			),
			'http://www.w3schools.com/cssref/css_websafe_fonts.asp'
		),
	);

	/*************************Menu****************************/

	$barberpro_mods['fonts']['options']['menu_font_size'] = array(
		'id' => 'menu_font_size',
		'label' => esc_html__( 'Menu Font Size for Desktop', 'barberpro' ),
		'type' => 'text',
		//'transport' => 'postMessage',
	);

	$barberpro_mods['fonts']['options']['menu_font_size_mobile'] = array(
		'id' => 'menu_font_size_mobile',
		'label' => esc_html__( 'Menu Font Size for Mobile', 'barberpro' ),
		'type' => 'text',
		//'transport' => 'postMessage',
	);

	$barberpro_mods['fonts']['options']['menu_font_name'] = array(
		'id' => 'menu_font_name',
		'label' => esc_html__( 'Menu Font', 'barberpro' ),
		'type' => 'select',
		'choices' => $barberpro_font_choices,
		//'transport' => 'postMessage',
	);

	$barberpro_mods['fonts']['options']['menu_font_weight'] = array(
		'label' => esc_html__( 'Menu Font Weight', 'barberpro' ),
		'id' => 'menu_font_weight',
		'type' => 'text',
	);

	$barberpro_mods['fonts']['options']['menu_font_transform'] = array(
		'id' => 'menu_font_transform',
		'label' => esc_html__( 'Menu Font Transform', 'barberpro' ),
		'type' => 'select',
		'choices' => array(
			'none' => esc_html__( 'None', 'barberpro' ),
			'uppercase' => esc_html__( 'Uppercase', 'barberpro' ),
		),
		//'transport' => 'postMessage',
	);

	$barberpro_mods['fonts']['options']['menu_font_style'] = array(
		'id' => 'menu_font_style',
		'label' => esc_html__( 'Menu Font Style', 'barberpro' ),
		'type' => 'select',
		'choices' => array(
			'normal' => esc_html__( 'Normal', 'barberpro' ),
			'italic' => esc_html__( 'Italic', 'barberpro' )
		),
		//'transport' => 'postMessage',
	);

	$barberpro_mods['fonts']['options']['menu_font_letter_spacing'] = array(
		'label' => esc_html__( 'Menu Letter Spacing (omit px)', 'barberpro' ),
		'id' => 'menu_font_letter_spacing',
		'type' => 'int',
	);

	/*************************Heading****************************/

	$barberpro_mods['fonts']['options']['heading_font_name'] = array(
		'id' => 'heading_font_name',
		'label' => esc_html__( 'Heading Font', 'barberpro' ),
		'type' => 'select',
		'choices' => $barberpro_font_choices,
		//'transport' => 'postMessage',
	);

	$barberpro_mods['fonts']['options']['heading_font_weight'] = array(
		'label' => esc_html__( 'Heading Font weight', 'barberpro' ),
		'id' => 'heading_font_weight',
		'type' => 'text',
		'description' => esc_html__( 'For example: 400 is normal, 700 is bold.The available font weights depend on the font. Leave empty to use the theme default style', 'barberpro' ),
	);

	$barberpro_mods['fonts']['options']['heading_font_transform'] = array(
		'id' => 'heading_font_transform',
		'label' => esc_html__( 'Heading Font Transform', 'barberpro' ),
		'type' => 'select',
		'choices' => array(
			'none' => esc_html__( 'None', 'barberpro' ),
			'uppercase' => esc_html__( 'Uppercase', 'barberpro' ),
		),
		//'transport' => 'postMessage',
	);

	$barberpro_mods['fonts']['options']['heading_font_style'] = array(
		'id' => 'heading_font_style',
		'label' => esc_html__( 'Heading Font Style', 'barberpro' ),
		'type' => 'select',
		'choices' => array(
			'normal' => esc_html__( 'Normal', 'barberpro' ),
			'italic' => esc_html__( 'Italic', 'barberpro' )
		),
		//'transport' => 'postMessage',
	);

	$barberpro_mods['fonts']['options']['heading_font_letter_spacing'] = array(
		'label' => esc_html__( 'Heading Letter Spacing (omit px)', 'barberpro' ),
		'id' => 'heading_font_letter_spacing',
		'type' => 'int',
	);

	return $barberpro_mods;
}
add_filter( 'barberpro_customizer_options', 'barberpro_set_fonts_mods' );