<?php
/**
 * BarberPro navigation
 *
 * @package WordPress
 * @subpackage BarberPro
 * @since BarberPro 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

function barberpro_set_navigation_mods( $barberpro_mods ) {

	$barberpro_mods['navigation'] = array(
		'id' => 'navigation',
		'icon' => 'menu',
		'title' => esc_html__( 'Navigation', 'barberpro' ),
		'options' => array(

			'ajax_nav' => array(
				'id' =>'ajax_nav',
				'label' => esc_html__( 'AJAX Navigation', 'barberpro' ),
				'type' => 'checkbox',
				'description' => esc_html__( 'Navigate without reloading the page.', 'barberpro' ),
			),

			'menu_layout' => array(
				'id' => 'menu_layout',
				'label' => esc_html__( 'Main Menu Layout', 'barberpro' ),
				'type' => 'select',
				'choices' => array(
					'standard' => esc_html__( 'Standard', 'barberpro' ),
					'centered' => esc_html__( 'Logo Centered', 'barberpro' ),
					'centered-socials' => esc_html__( 'Centered with Social Icons at Right', 'barberpro' ),
					'centered-blog' => esc_html__( 'Centered with Search Icon at Right', 'barberpro' ),
				),
				'description' => esc_html__( 'Create your menu(s) accordingly in the menu admin panel.', 'barberpro' ),
			),

			'menu_width' => array(
				'id' => 'menu_width',
				'label' => esc_html__( 'Main Menu Width for Standard Style', 'barberpro' ),
				'type' => 'select',
				'choices' => array(
					'boxed' => esc_html__( 'Boxed', 'barberpro' ),
					'wide' => esc_html__( 'Wide', 'barberpro' ),
					'fullwidth' => esc_html__( '100% Width', 'barberpro' ),
				),
				'transport' => 'postMessage',
			),

			'menu_centered_alignment' => array(
				'id' => 'menu_centered_alignment',
				'label' => esc_html__( 'Main Menu Alignment for Logo Centered Style', 'barberpro' ),
				'type' => 'select',
				'choices' => array(
					'boxed' => esc_html__( 'Boxed (menu item close to the logo)', 'barberpro' ),
					'wide' => esc_html__( 'Wide (menu items far from the logo)', 'barberpro' ),
				),
				'transport' => 'postMessage',
			),

			'auto_menu_type' => array(
				'id' =>'auto_menu_type',
				'label' => esc_html__( 'Main Menu Style', 'barberpro' ),
				'type' => 'select',
				'choices' => array(
					'semi-transparent' => esc_html__( 'Semi-transparent White', 'barberpro' ),
					'semi-transparent-black' => esc_html__( 'Semi-transparent Black', 'barberpro' ),
					'standard' => esc_html__( 'Solid', 'barberpro' ),
					'absolute' => esc_html__( 'Absolute position', 'barberpro' ),
					'transparent' => esc_html__( 'Transparent', 'barberpro' ),
				),
			),

			'menu_hover_style' => array(
				'id' => 'menu_hover_style',
				'label' => esc_html__( 'Main Menu Hover Style', 'barberpro' ),
				'type' => 'select',
				'choices' => apply_filters( 'barberpro_main_menu_hover_style_options', array(
					'none' => esc_html__( 'None', 'barberpro' ),
					'opacity' => esc_html__( 'Opacity', 'barberpro' ),
					'line' => esc_html__( 'Line', 'barberpro' ),
					'line2' => esc_html__( 'Line 2', 'barberpro' ),
					'border' => esc_html__( 'Border', 'barberpro' ),
					'plain' => esc_html__( 'Plain', 'barberpro' ),
				) ),
				'transport' => 'postMessage',
			),

			'main_menu_item_separator' => array(
				'id' => 'main_menu_item_separator',
				'label' => esc_html__( 'Main Menu Item Separator', 'barberpro' ),
				'type' => 'text',
				'description' => sprintf( wp_kses(
					__( 'This will be output via CSS, so you need to use ISO format if you want to use special characters (<a href="%s" target="_blank">cheat sheet</a>).', 'barberpro' ),
						array( 'a' => array( 'href' => array(), 'target' => array(), ) )
					),
					esc_url( 'https://brajeshwar.github.io/entities/' )
				),
			),

			// 'sub_menu_color' => array(
			// 	'id' =>'sub_menu_color',
			// 	'label' => esc_html__( 'Submenu Color', 'barberpro' ),
			// 	'type' => 'color',
			// ),

			'submenu_width' => array(
				'id' => 'submenu_width',
				'label' => esc_html__( 'Mega Menu Width', 'barberpro' ),
				'type' => 'select',
				'choices' => array(
					'boxed' => esc_html__( 'Boxed', 'barberpro' ),
					'wide' => esc_html__( 'Wide', 'barberpro' ),
				),
				'transport' => 'postMessage',
			),

			'menu_height' => array(
				'id' =>'menu_height',
				'label' => esc_html__( 'Menu Height in px', 'barberpro' ),
				'type' => 'text',
				//'transport' => 'postMessage',
			),

			'menu_item_padding' => array(
				'id' =>'menu_item_padding',
				'label' => esc_html__( 'Menu item horizontal padding in px', 'barberpro' ),
				'type' => 'text',
			),

			// 'menu_font_size' => array(
			// 	'id' =>'menu_font_size',
			// 	'label' => esc_html__( 'Menu font size', 'barberpro' ),
			// 	'type' => 'text',
			// ),

			'menu_breakpoint' => array(
				'id' =>'menu_breakpoint',
				'label' => esc_html__( 'Main Menu Breakpoint', 'barberpro' ),
				'type' => 'text',
				'description' => esc_html__( 'Below each width would you like to display the mobile menu? 0 will always show the desktop menu and 99999 will always show the mobile menu.', 'barberpro' ),
			),

			'sticky_menu' => array(
				'id' =>'sticky_menu',
				'label' => esc_html__( 'Sticky Menu', 'barberpro' ),
				'type' => 'checkbox',
				'description' => esc_html__( 'The menu will stay at the top while scrolling.', 'barberpro' ),
			),

			'menu_bottom_border' => array(
				'label' => esc_html__( 'Menu Bottom Border', 'barberpro' ),
				'id' => 'menu_bottom_border',
				'type' => 'checkbox',
			),

			'search_menu_item' => array(
				'label' => esc_html__( 'Search Menu Item', 'barberpro' ),
				'id' => 'search_menu_item',
				'type' => 'select',
				'choices' => array(
					'overlay' => esc_html__( 'Overlay', 'barberpro' ),
					'' => esc_html__( 'No Search Menu Item', 'barberpro' ),
				),
			),

			'search_menu_item_icon' => array(
				'label' => esc_html__( 'Search Menu Item Icon', 'barberpro' ),
				'id' => 'search_menu_item_icon',
				'type' => 'select',
				'choices' => array(
					'fa-search' => esc_html__( 'Icon 1', 'barberpro' ),
					'line-icon-search' => esc_html__( 'Icon 2', 'barberpro' ),
				),
			),
		),
	);

	if ( apply_filters( 'barberpro_display_topbar', '' ) ) {
		$barberpro_mods['navigation']['options']['topbar_content'] = array(
			'label' => esc_html__( 'Optional content to display in the top bar.', 'barberpro' ),
			'id' => 'topbar_content',
			'type' => 'text',
		);
	}

	if ( class_exists( 'WooCommerce' ) ) {
		$barberpro_mods['navigation']['options']['menu_layout']['choices']['centered-shop'] = esc_html__( 'Centered with Cart Icon at Right', 'barberpro' );
	}

	if ( function_exists( 'icl_object_id' ) ) {
		$barberpro_mods['navigation']['options']['menu_layout']['choices']['centered-wpml'] = esc_html__( 'Centered with Language Switcher at Right', 'barberpro' );
	}

	if ( class_exists( 'Wolf_Page_Builder' ) ) {
		$barberpro_mods['navigation']['options']['menu_socials_services'] = array(
			'id' =>'menu_socials_services',
			'label' => esc_html__( 'Menu Socials', 'barberpro' ),
			'description' => sprintf( wp_kses(
				__( 'Enter the social networks names separated by a comma. e.g "twitter, facebook, instagram". ( see Wolf Page Builder options <a href="%s">social profiles tab</a>).', 'barberpro' ),
					array( 'a' => array( 'href' => array(), ) )
				),
				esc_url( admin_url( 'admin.php?page=wpb-socials' ) )
			),
			'type' => 'text',
		);
	}

	return $barberpro_mods;
}
add_filter( 'barberpro_customizer_options', 'barberpro_set_navigation_mods' );